#clear workspace
rm(list = ls())
#set true to export png
ExportPNG <- TRUE
#ExportPNG <- FALSE

#load data
source("20221014_LoadData.r")

print("Age")
z<-table(rawdata[4])
if (ExportPNG) png("Age.png",width=640,height=640)
pie( z[which=c("18 - 25","26 - 35","36 - 45","46 - 55", "56 - 65", "Above 65")], main="How old are you?",
     col = rainbow(6, alpha = 0.5), cex=1.5, cex.axis=1.5, cex.main=2)
if (ExportPNG) dev.off() else dev.new()
rm(z)

#print("OS")
#z <- c(table(rawdata[5]),table(rawdata[6]),table(rawdata[7]))
#if (ExportPNG) png("OS.png",width=640,height=640)
#pie( z[c(2,4,6)], labels=c("Windows","macOS","Linux"), main="Which operating system do you use on your PC?",
#     col=c("cadetblue1","lightpink","darkolivegreen1"), cex=1.5, cex.axis=1.5, cex.main=2)
#if (ExportPNG) dev.off() else dev.new()
#rm(z)

print("OS")
if (!require("eulerr")) {
   install.packages("eulerr", dependencies = TRUE)
   library(euler)
   }
VennDiag <- euler(c("Windows" = matrix(table(rawdata[5]))[2], 
                    "macOS" =   matrix(table(rawdata[6]))[2],
                    "Linux" =   matrix(table(rawdata[7]))[2], 
                    "Windows&macOS"       = matrix(table(rawdata[ which(rawdata[6] == "Yes" & rawdata[7] == "No"), 5 ]))[2],
                    "macOS&Linux"         = matrix(table(rawdata[ which(rawdata[6] == "Yes" & rawdata[5] == "No"), 7 ]))[2],
                    "Windows&Linux"       = matrix(table(rawdata[ which(rawdata[5] == "Yes" & rawdata[6] == "No"), 7 ]))[2],
                    "Windows&macOS&Linux" = matrix(table(rawdata[ which(rawdata[5] == "Yes" & rawdata[6] == "Yes"), 7 ]))[2]
                  ))
p<-plot(VennDiag, 
        quantities = list(cex = 1.2),
        labels = list(cex = 1.5),
        main = list(label="\nWhich operating system do you use on your PC?", cex=2, fontface = "bold"),
        fill = rainbow(7,alpha=0.5), alpha=0.4)
if (ExportPNG) png("OS.png",width=640,height=640)
print(p)
if (ExportPNG) dev.off() else dev.new()
rm(VennDiag)
rm(p)

print("Frequency")
z<-table(rawdata[8])
if (ExportPNG) png("Freq.png",width=640,height=640)
pie( z[which=c("Everyday","Weekly","Fortnightly","Monthly","A few times a year")],
     main="How often do you use LibreOffice Impress?",
     col = rainbow(5, alpha = 0.5), cex=1.5, cex.axis=1.5, cex.main=2)
if (ExportPNG) dev.off() else dev.new()
rm(z)

print("Slides")
z<-rawdata[9][!is.na(rawdata[9])]
if (ExportPNG) png("slides.png",width=640,height=640)
hist(z, main = "How many slides does your presentation\nhave in general?", xlab="n (slides)",
        cex=1.5, cex.axis=1.5, cex.main=2, cex.lab=1.5)
if (ExportPNG) dev.off() else dev.new()
rm(z)

print("Where")
if (!require("eulerr")) {
   install.packages("eulerr", dependencies = TRUE)
   library(euler)
   }
VennDiag <- euler(c("Work"    = matrix(table(rawdata[10]))[2], 
                    "School"  = matrix(table(rawdata[11]))[2],
                    "Private" = matrix(table(rawdata[12]))[2], 
                    "Work&School"    = matrix(table(rawdata[ which(rawdata[10] == "Yes" & rawdata[12] == "No"), 11 ]))[2],
                    "School&Private" = matrix(table(rawdata[ which(rawdata[11] == "Yes" & rawdata[10] == "No"), 12 ]))[2],
                    "Work&Private"   = matrix(table(rawdata[ which(rawdata[10] == "Yes" & rawdata[11] == "No"), 12 ]))[2],
                    "Work&School&Private" = matrix(table(rawdata[ which(rawdata[10] == "Yes" & rawdata[11] == "Yes"), 12 ]))[2]
                  ))
p<-plot(VennDiag, 
        quantities = list(cex = 1.2),
        labels = list(cex = 1.5),
        main = list(label="\nWhat type of user are you??", cex=2, fontface = "bold"),
        fill = rainbow(7,alpha=0.5), alpha=0.4)
if (ExportPNG) png("Where.png",width=640,height=640)
print(p)
if (ExportPNG) dev.off() else dev.new()
rm(VennDiag)
rm(p)

print("Tools")
z<-c(table(rawdata[13]))
for (i in 14:19) z <- cbind(z,table(rawdata[i]))
if (ExportPNG) png("Tools.png",width=950,height=480)
par(mar=c(7, 4, 6, 6))
barplot(z, col=c("lightpink","darkolivegreen1"), 
           names.arg=c("\nMicrosoft\nPowerPoint", "\nGoogle\nSlides", "\nAdobe\nInDesign", "Canva", "Piktochart", "LucidPress", "Prezi"),
           main="What other software do you / have you used\nto create your presentation?",
           legend.text=c("No","Yes"),
           args.legend=list(x=9.2, y=170, bty = "n", cex=1.5),
           xlim=c(0,8), cex=1.15, cex.axis=1.5, cex.main=2.0
       )
if (ExportPNG) dev.off() else dev.new()
rm(z)

print("Functions")
if (!require("likert")) {
   install.packages("likert", dependencies = TRUE)
   library(likert)
   }
if (!require("stringr")) { #str_wrap
   install.packages("stringr", dependencies = TRUE)
   library(stringr)
   }
z<-subset(rawdata[20:33])
colnames(z)<-c("Loop", "Presentation Console", "Media Player", "Templates", "Sort & Filter", 
               "Export As (e.g. PDF, XTHML, JPEG, PNG)", "Insert Objects, Shapes & Images", 
               "Slide Show\n(e.g. Rehearse Timings, Custome Slide Show)", "Text Formatting\n(e.g. Alignment, Spacing)", 
               "Animation & Effects", "Layouts", "UI Settings", "Tools\n(e.g. Spell Checking, Language)", 
               "Presentation Minimizer")
for(i in seq_along(z)) {
  z[i][z[i] == "Not Familiar with this Feature"]<-"0"
  z[i][z[i] == "I don't like it at all - 1"]<-1
  z[i][z[i] == "I like it very much - 5"]<-5
  z[i][z[i] == ""]<-6 #to have 3 in the center
  z[,i] <- as.factor(z[,i])
}
lik<-likert(z)
colnames(lik$results)[2] <- "Not Familiar with this Feature"
notfam<-lik$results[,c(1,2)] #Not Familiar with this Feature
#summary(lik,center=4) #returns the sort order
notfam<-notfam[c(6,9,7,8,13,2,12,11,14,10,5,4,1,3),] #sort by likert results
if (ExportPNG) png("Likert.png",width=1024,height=680)
p<-plot(lik, plot.percent.neutral=FALSE, 
        colors=c("#ffffff","#d8b365","#ebd9b2","#e5e5e5","#acd9d5","#5ab4ac","#ffffff"), #hide "Not familiar" and no answer (0,6) by making it white
        text.color="#AAAAAA", legend.position="right") +
        theme(text = element_text(size=18)) +
        ggtitle(str_wrap("How do you feel about each of the following features based on your experience?", 60)) +
        annotate("rect", xmin = 13.5, xmax = 14.4, ymin = -100, ymax = -100 + notfam[ 1,2], alpha = .5) +
        annotate("rect", xmin = 12.5, xmax = 13.4, ymin = -100, ymax = -100 + notfam[ 2,2], alpha = .5) +
        annotate("rect", xmin = 11.5, xmax = 12.4, ymin = -100, ymax = -100 + notfam[ 3,2], alpha = .5) +
        annotate("rect", xmin = 10.5, xmax = 11.4, ymin = -100, ymax = -100 + notfam[ 4,2], alpha = .5) +
        annotate("rect", xmin =  9.5, xmax = 10.4, ymin = -100, ymax = -100 + notfam[ 5,2], alpha = .5) +
        annotate("rect", xmin =  8.5, xmax =  9.4, ymin = -100, ymax = -100 + notfam[ 6,2], alpha = .5) +
        annotate("rect", xmin =  7.5, xmax =  8.4, ymin = -100, ymax = -100 + notfam[ 7,2], alpha = .5) +
        annotate("rect", xmin =  6.5, xmax =  7.4, ymin = -100, ymax = -100 + notfam[ 8,2], alpha = .5) +
        annotate("rect", xmin =  5.5, xmax =  6.4, ymin = -100, ymax = -100 + notfam[ 9,2], alpha = .5) +
        annotate("rect", xmin =  4.5, xmax =  5.4, ymin = -100, ymax = -100 + notfam[10,2], alpha = .5) +
        annotate("rect", xmin =  3.5, xmax =  4.4, ymin = -100, ymax = -100 + notfam[11,2], alpha = .5) +
        annotate("rect", xmin =  2.5, xmax =  3.4, ymin = -100, ymax = -100 + notfam[12,2], alpha = .5) +
        annotate("rect", xmin =  1.5, xmax =  2.4, ymin = -100, ymax = -100 + notfam[13,2], alpha = .5) +
        annotate("rect", xmin =  0.5, xmax =  1.4, ymin = -100, ymax = -100 + notfam[14,2], alpha = .5)
print(p)     #print() to export png
if (ExportPNG) dev.off() else dev.new()
rm(z)
rm(lik)
rm(notfam)

print("Recommendation")
z<-table(rawdata[34])
if (ExportPNG) png("Recomend.png",width=640,height=640)
pie( z[which=c("Very likely","Likely","Unlikely","Very unlikely")],
     main="How likely would you recommend LibreOffice Impress\nto your friend or colleague?",
     col = c("darkgreen","green","red","darkred"), 
     cex=1.5, cex.axis=1.5, cex.main=2)
if (ExportPNG) dev.off() else dev.new()
rm(z)

print("SUS")
rawdata <- subset(rawdata, Lastpage == 3)
#x<-0
y<-0
z<-0
#x <- rawdata[8]
#x[x=="Everyday"] <- 1
#x[x=="Weekly"] <- 1
#x[x=="Fortnightly"] <- 2
#x[x=="Monthly"] <- 2
#x[x=="A few times a year"] <- 2
#x[x==""] <- NA
for (i in 35:44) {
    z <- rawdata[i]
    z[z=="Strongly Disagree - 1"] <- 1
    z[z=="Strongly Agree - 5"] <- 5
    if (((i-34) %% 2) == 1)
       y <- y + as.numeric(unlist(z))-1
    else
       y <- y + 5-as.numeric(unlist(z))
}
y <- y*2.5
if (ExportPNG) png("SUS.png",width=640,height=640)
boxplot(x=c(),ylim=c(0,100), cex.axis=1.5)
rect(0,80.3,2,100, col="#D0FFD0",border = NA) #score A
rect(0,68,2,80.3,col="#FFFFD0",border = NA) #score B
rect(0,51,2,68,col="#FFE7D0",border = NA) #score C
rect(0,0.1,2,51.2,col="#FFD0D0",border = NA) #score F
par(new=TRUE)
boxplot(y,# ~ unlist(x), 
        outline=FALSE, main="System Usability Scale", 
        # names=c("Frequently","Rarely"),
        ylim=c(0,100), col=FALSE, xlab="", ylab="", cex.main=2, cex.lab=1.5, cex.axis=1.5)
#print(paste("SUS: ",mean(y[x==1],na.rm=T),",",mean(y[x==2],na.rm=T),",",mean(y[x==3],na.rm=T)))
if (ExportPNG) dev.off() else dev.new()
#rm(x)
rm(y)
rm(z)
